"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupCI = void 0;
const tslib_1 = require("tslib");
const ora = require("ora");
const path_1 = require("path");
const child_process_utils_1 = require("../child-process-utils");
const output_1 = require("../output");
const package_manager_1 = require("../package-manager");
const string_utils_1 = require("../string-utils");
function setupCI(name, ci, packageManager, nxCloudSuccessfullyInstalled) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!nxCloudSuccessfullyInstalled) {
            output_1.output.error({
                title: `CI workflow generation skipped`,
                bodyLines: [
                    `Nx Cloud was not installed`,
                    `The autogenerated CI workflow requires Nx Cloud to be set-up.`,
                ],
            });
        }
        const ciSpinner = ora(`Generating CI workflow`).start();
        try {
            const pmc = (0, package_manager_1.getPackageManagerCommand)(packageManager);
            const res = yield (0, child_process_utils_1.execAndWait)(`${pmc.exec} nx g @nrwl/workspace:ci-workflow --ci=${ci}`, (0, path_1.join)(process.cwd(), (0, string_utils_1.getFileName)(name)));
            ciSpinner.succeed('CI workflow has been generated successfully');
            return res;
        }
        catch (e) {
            ciSpinner.fail();
            output_1.output.error({
                title: `Nx failed to generate CI workflow`,
                bodyLines: (0, string_utils_1.mapErrorToBodyLines)(e),
            });
            process.exit(1);
        }
        finally {
            ciSpinner.stop();
        }
    });
}
exports.setupCI = setupCI;
//# sourceMappingURL=setup-ci.js.map