"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getThirdPartyPreset = void 0;
const tslib_1 = require("tslib");
const output_1 = require("../output");
const validate_npm_package_1 = require("../validate-npm-package");
const preset_1 = require("./preset");
/**
 * This function is used to check if a preset is a third party preset.
 * @param preset
 * @returns null if the preset is a known Nx preset or preset does not exist, the normalized preset otherwise.
 */
function getThirdPartyPreset(preset) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (preset && !(0, preset_1.isKnownPreset)(preset)) {
            const packageName = preset.match(/.+@/)
                ? preset[0] + preset.substring(1).split('@')[0]
                : preset;
            const validateResult = (0, validate_npm_package_1.validateNpmPackage)(packageName);
            if (validateResult.validForNewPackages) {
                return Promise.resolve(preset);
            }
            else {
                //! Error here
                output_1.output.error({
                    title: 'Invalid preset npm package',
                    bodyLines: [
                        `There was an error with the preset npm package you provided:`,
                        '',
                        ...validateResult.errors,
                    ],
                });
                throw new Error('Invalid preset npm package');
            }
        }
        else {
            return Promise.resolve(null);
        }
    });
}
exports.getThirdPartyPreset = getThirdPartyPreset;
//# sourceMappingURL=get-third-party-preset.js.map